# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `anova` Chapter.
"""

# NAG Copyright 2017-2019.

from ..base import utils

hier2 = utils._EngineState._get_symbol('g04agf')
hier2.restype = None
hier2.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineIntArrayType.c_type, # Input, lsub[k].
    utils._EngineIntArrayType.c_type, # Input, nobs[l].
    utils._BYREF_INT, # Input, l.
    utils._EngineIntArrayType.c_type, # Output, ngp[k].
    utils._EngineFloat64ArrayType.c_type, # Output, gbar[k].
    utils._EngineFloat64ArrayType.c_type, # Output, sgbar[l].
    utils._BYREF_FLOAT64, # Output, gm.
    utils._EngineFloat64ArrayType.c_type, # Output, ss[4].
    utils._EngineIntArrayType.c_type, # Output, idf[4].
    utils._EngineFloat64ArrayType.c_type, # Output, f[2].
    utils._EngineFloat64ArrayType.c_type, # Output, fp[2].
    utils._BYREF_INT, # Input/Output, ifail.
)

random = utils._EngineState._get_symbol('g04bbf')
random.restype = None
random.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_INT, # Input, iblock.
    utils._BYREF_INT, # Input, nt.
    utils._EngineIntArrayType.c_type, # Input, it[*].
    utils._BYREF_FLOAT64, # Output, gmean.
    utils._EngineFloat64ArrayType.c_type, # Output, bmean[abs(iblock)].
    utils._EngineFloat64ArrayType.c_type, # Output, tmean[nt].
    utils._EngineFloat64ArrayType.c_type, # Output, tabl[ldtabl, 5].
    utils._BYREF_INT, # Input, ldtabl.
    utils._EngineFloat64ArrayType.c_type, # Output, c[ldc, nt].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineIntArrayType.c_type, # Output, irep[nt].
    utils._EngineFloat64ArrayType.c_type, # Output, r[n].
    utils._EngineFloat64ArrayType.c_type, # Output, ef[nt].
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, irdf.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[3*nt].
    utils._BYREF_INT, # Input/Output, ifail.
)

rowcol = utils._EngineState._get_symbol('g04bcf')
rowcol.restype = None
rowcol.argtypes = (
    utils._BYREF_INT, # Input, nrep.
    utils._BYREF_INT, # Input, nrow.
    utils._BYREF_INT, # Input, ncol.
    utils._EngineFloat64ArrayType.c_type, # Input, y[nrep*nrow*ncol].
    utils._BYREF_INT, # Input, nt.
    utils._EngineIntArrayType.c_type, # Input, it[*].
    utils._BYREF_FLOAT64, # Output, gmean.
    utils._EngineFloat64ArrayType.c_type, # Output, tmean[nt].
    utils._EngineFloat64ArrayType.c_type, # Output, tabl[ldtabl, 5].
    utils._BYREF_INT, # Input, ldtabl.
    utils._EngineFloat64ArrayType.c_type, # Output, c[ldc, nt].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineIntArrayType.c_type, # Output, irep[nt].
    utils._EngineFloat64ArrayType.c_type, # Output, rpmean[nrep].
    utils._EngineFloat64ArrayType.c_type, # Output, rmean[nrep*nrow].
    utils._EngineFloat64ArrayType.c_type, # Output, cmean[nrep*ncol].
    utils._EngineFloat64ArrayType.c_type, # Output, r[nrep*nrow*ncol].
    utils._EngineFloat64ArrayType.c_type, # Output, ef[nt].
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, irdf.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[3*nt].
    utils._BYREF_INT, # Input/Output, ifail.
)

factorial = utils._EngineState._get_symbol('g04caf')
factorial.restype = None
factorial.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_INT, # Input, nfac.
    utils._EngineIntArrayType.c_type, # Input, lfac[nfac].
    utils._BYREF_INT, # Input, nblock.
    utils._BYREF_INT, # Input, inter.
    utils._BYREF_INT, # Input, irdf.
    utils._BYREF_INT, # Input, mterm.
    utils._EngineFloat64ArrayType.c_type, # Output, table[mterm, 5].
    utils._BYREF_INT, # Output, itotal.
    utils._EngineFloat64ArrayType.c_type, # Output, tmean[maxt].
    utils._BYREF_INT, # Input, maxt.
    utils._EngineFloat64ArrayType.c_type, # Output, e[maxt].
    utils._EngineIntArrayType.c_type, # Output, imean[mterm].
    utils._EngineFloat64ArrayType.c_type, # Output, semean[mterm].
    utils._EngineFloat64ArrayType.c_type, # Output, bmean[nblock+1].
    utils._EngineFloat64ArrayType.c_type, # Output, r[n].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[n+3*nfac].
    utils._BYREF_INT, # Input/Output, ifail.
)

contrasts = utils._EngineState._get_symbol('g04daf')
contrasts.restype = None
contrasts.argtypes = (
    utils._BYREF_INT, # Input, nt.
    utils._EngineFloat64ArrayType.c_type, # Input, tmean[nt].
    utils._EngineIntArrayType.c_type, # Input, irep[nt].
    utils._BYREF_FLOAT64, # Input, rms.
    utils._BYREF_FLOAT64, # Input, rdf.
    utils._BYREF_INT, # Input, nc.
    utils._EngineFloat64ArrayType.c_type, # Input, ct[ldct, nc].
    utils._BYREF_INT, # Input, ldct.
    utils._EngineFloat64ArrayType.c_type, # Output, est[nc].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, tabl[ldtabl, *].
    utils._BYREF_INT, # Input, ldtabl.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_LOGICAL, # Input, usetx.
    utils._EngineFloat64ArrayType.c_type, # Input, tx[nt].
    utils._BYREF_INT, # Input/Output, ifail.
)

confidence = utils._EngineState._get_symbol('g04dbf')
confidence.restype = None
confidence.argtypes = (
    utils._BYREF_STRING, # Input, typ(len=1).
    utils._BYREF_INT, # Input, nt.
    utils._EngineFloat64ArrayType.c_type, # Input, tmean[nt].
    utils._BYREF_FLOAT64, # Input, rdf.
    utils._EngineFloat64ArrayType.c_type, # Input, c[ldc, nt].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_FLOAT64, # Input, clevel.
    utils._EngineFloat64ArrayType.c_type, # Output, cil[nt*(nt-1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, ciu[nt*(nt-1)/2].
    utils._EngineIntArrayType.c_type, # Output, isig[nt*(nt-1)/2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of typ.
)

dummyvars = utils._EngineState._get_symbol('g04eaf')
dummyvars.restype = None
dummyvars.argtypes = (
    utils._BYREF_STRING, # Input, typ(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, levels.
    utils._EngineIntArrayType.c_type, # Input, ifact[n].
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Input, v[*].
    utils._EngineFloat64ArrayType.c_type, # Output, rep[levels].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of typ.
)

icc = utils._EngineState._get_symbol('g04gaf')
icc.restype = None
icc.argtypes = (
    utils._BYREF_INT, # Input, mtype.
    utils._BYREF_INT, # Input, rtype.
    utils._BYREF_INT, # Input, nrep.
    utils._BYREF_INT, # Input, nsubj.
    utils._BYREF_INT, # Input, nrater.
    utils._EngineFloat64ArrayType.c_type, # Input, score[nrep, nsubj, nrater].
    utils._BYREF_INT, # Input, mscore.
    utils._BYREF_FLOAT64, # Input, smiss.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._BYREF_FLOAT64, # Output, icc.
    utils._BYREF_FLOAT64, # Output, lci.
    utils._BYREF_FLOAT64, # Output, uci.
    utils._BYREF_FLOAT64, # Output, fstat.
    utils._BYREF_FLOAT64, # Output, df1.
    utils._BYREF_FLOAT64, # Output, df2.
    utils._BYREF_FLOAT64, # Output, pvalue.
    utils._BYREF_INT, # Input/Output, ifail.
)
