# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `interp` Chapter.
"""

# NAG Copyright 2017-2019.

from ..base import utils

dim1_aitken = utils._EngineState._get_symbol('e01aaf')
dim1_aitken.restype = None
dim1_aitken.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[n+1].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[n+1].
    utils._EngineFloat64ArrayType.c_type, # Output, c[n*(n+1)/2].
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, x.
)

dim1_everett = utils._EngineState._get_symbol('e01abf')
dim1_everett.restype = None
dim1_everett.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, p.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[2*n].
    utils._EngineFloat64ArrayType.c_type, # Output, g[2*n+1].
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_cheb = utils._EngineState._get_symbol('e01aef')
dim1_cheb.restype = None
dim1_cheb.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input, xmin.
    utils._BYREF_FLOAT64, # Input, xmax.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._EngineIntArrayType.c_type, # Input, ip[m].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, itmin.
    utils._BYREF_INT, # Input, itmax.
    utils._EngineFloat64ArrayType.c_type, # Output, a[n].
    utils._EngineFloat64ArrayType.c_type, # Output, wrk[lwrk].
    utils._BYREF_INT, # Input, lwrk.
    utils._EngineIntArrayType.c_type, # Output, iwrk[liwrk].
    utils._BYREF_INT, # Input, liwrk.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_spline = utils._EngineState._get_symbol('e01baf')
dim1_spline.restype = None
dim1_spline.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._EngineFloat64ArrayType.c_type, # Output, lamda[lck].
    utils._EngineFloat64ArrayType.c_type, # Output, c[lck].
    utils._BYREF_INT, # Input, lck.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[lwrk].
    utils._BYREF_INT, # Input, lwrk.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_monotonic = utils._EngineState._get_symbol('e01bef')
dim1_monotonic.restype = None
dim1_monotonic.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, f[n].
    utils._EngineFloat64ArrayType.c_type, # Output, d[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_monotonic_eval = utils._EngineState._get_symbol('e01bff')
dim1_monotonic_eval.restype = None
dim1_monotonic_eval.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, f[n].
    utils._EngineFloat64ArrayType.c_type, # Input, d[n].
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, px[m].
    utils._EngineFloat64ArrayType.c_type, # Output, pf[m].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_monotonic_deriv = utils._EngineState._get_symbol('e01bgf')
dim1_monotonic_deriv.restype = None
dim1_monotonic_deriv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, f[n].
    utils._EngineFloat64ArrayType.c_type, # Input, d[n].
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, px[m].
    utils._EngineFloat64ArrayType.c_type, # Output, pf[m].
    utils._EngineFloat64ArrayType.c_type, # Output, pd[m].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_monotonic_intg = utils._EngineState._get_symbol('e01bhf')
dim1_monotonic_intg.restype = None
dim1_monotonic_intg.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, f[n].
    utils._EngineFloat64ArrayType.c_type, # Input, d[n].
    utils._BYREF_FLOAT64, # Input, a.
    utils._BYREF_FLOAT64, # Input, b.
    utils._BYREF_FLOAT64, # Output, pint.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_monconv_disc = utils._EngineState._get_symbol('e01cef')
dim1_monconv_disc.restype = None
dim1_monconv_disc.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, lam.
    utils._BYREF_LOGICAL, # Input, negfor.
    utils._BYREF_LOGICAL, # Input, yfor.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._EngineFloat64ArrayType.c_type, # Output, comm[4*n+10].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_monconv_eval = utils._EngineState._get_symbol('e01cff')
dim1_monconv_eval.restype = None
dim1_monconv_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Output, val[m].
    utils._EngineFloat64ArrayType.c_type, # Output, fwd[m].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_spline_grid = utils._EngineState._get_symbol('e01daf')
dim2_spline_grid.restype = None
dim2_spline_grid.argtypes = (
    utils._BYREF_INT, # Input, mx.
    utils._BYREF_INT, # Input, my.
    utils._EngineFloat64ArrayType.c_type, # Input, x[mx].
    utils._EngineFloat64ArrayType.c_type, # Input, y[my].
    utils._EngineFloat64ArrayType.c_type, # Input, f[mx*my].
    utils._BYREF_INT, # Output, px.
    utils._BYREF_INT, # Output, py.
    utils._EngineFloat64ArrayType.c_type, # Output, lamda[mx+4].
    utils._EngineFloat64ArrayType.c_type, # Output, mu[my+4].
    utils._EngineFloat64ArrayType.c_type, # Output, c[mx*my].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[(mx+6)*(my+6)].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_triangulate = utils._EngineState._get_symbol('e01eaf')
dim2_triangulate.restype = None
dim2_triangulate.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._EngineIntArrayType.c_type, # Output, triang[7*n].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_triang_bary_eval = utils._EngineState._get_symbol('e01ebf')
dim2_triang_bary_eval.restype = None
dim2_triang_bary_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._EngineFloat64ArrayType.c_type, # Input, f[n].
    utils._EngineIntArrayType.c_type, # Input, triang[7*n].
    utils._EngineFloat64ArrayType.c_type, # Input, px[m].
    utils._EngineFloat64ArrayType.c_type, # Input, py[m].
    utils._EngineFloat64ArrayType.c_type, # Output, pf[m].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_ratnl = utils._EngineState._get_symbol('e01raf')
dim1_ratnl.restype = None
dim1_ratnl.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, f[n].
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, a[n].
    utils._EngineFloat64ArrayType.c_type, # Output, u[n].
    utils._EngineIntArrayType.c_type, # Workspace, iw[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_ratnl_eval = utils._EngineState._get_symbol('e01rbf')
dim1_ratnl_eval.restype = None
dim1_ratnl_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, a[m].
    utils._EngineFloat64ArrayType.c_type, # Input, u[m].
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Output, f.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_scat = utils._EngineState._get_symbol('e01saf')
dim2_scat.restype = None
dim2_scat.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._EngineIntArrayType.c_type, # Output, triang[7*m].
    utils._EngineFloat64ArrayType.c_type, # Output, grads[2, m].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_scat_eval = utils._EngineState._get_symbol('e01sbf')
dim2_scat_eval.restype = None
dim2_scat_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._EngineIntArrayType.c_type, # Input, triang[7*m].
    utils._EngineFloat64ArrayType.c_type, # Input, grads[2, m].
    utils._BYREF_FLOAT64, # Input, px.
    utils._BYREF_FLOAT64, # Input, py.
    utils._BYREF_FLOAT64, # Output, pf.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_scat_shep = utils._EngineState._get_symbol('e01sgf')
dim2_scat_shep.restype = None
dim2_scat_shep.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._BYREF_INT, # Input, nw.
    utils._BYREF_INT, # Input, nq.
    utils._EngineIntArrayType.c_type, # Output, iq[liq].
    utils._BYREF_INT, # Input, liq.
    utils._EngineFloat64ArrayType.c_type, # Output, rq[lrq].
    utils._BYREF_INT, # Input, lrq.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_scat_shep_eval = utils._EngineState._get_symbol('e01shf')
dim2_scat_shep_eval.restype = None
dim2_scat_shep_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._EngineIntArrayType.c_type, # Input, iq[liq].
    utils._BYREF_INT, # Input, liq.
    utils._EngineFloat64ArrayType.c_type, # Input, rq[lrq].
    utils._BYREF_INT, # Input, lrq.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, u[n].
    utils._EngineFloat64ArrayType.c_type, # Input, v[n].
    utils._EngineFloat64ArrayType.c_type, # Output, q[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qx[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qy[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim3_scat_shep = utils._EngineState._get_symbol('e01tgf')
dim3_scat_shep.restype = None
dim3_scat_shep.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._EngineFloat64ArrayType.c_type, # Input, z[m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._BYREF_INT, # Input, nw.
    utils._BYREF_INT, # Input, nq.
    utils._EngineIntArrayType.c_type, # Output, iq[liq].
    utils._BYREF_INT, # Input, liq.
    utils._EngineFloat64ArrayType.c_type, # Output, rq[lrq].
    utils._BYREF_INT, # Input, lrq.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim3_scat_shep_eval = utils._EngineState._get_symbol('e01thf')
dim3_scat_shep_eval.restype = None
dim3_scat_shep_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[m].
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._EngineFloat64ArrayType.c_type, # Input, z[m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._EngineIntArrayType.c_type, # Input, iq[liq].
    utils._BYREF_INT, # Input, liq.
    utils._EngineFloat64ArrayType.c_type, # Input, rq[lrq].
    utils._BYREF_INT, # Input, lrq.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, u[n].
    utils._EngineFloat64ArrayType.c_type, # Input, v[n].
    utils._EngineFloat64ArrayType.c_type, # Input, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, q[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qx[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qy[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qz[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim4_scat_shep = utils._EngineState._get_symbol('e01tkf')
dim4_scat_shep.restype = None
dim4_scat_shep.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[4, m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._BYREF_INT, # Input, nw.
    utils._BYREF_INT, # Input, nq.
    utils._EngineIntArrayType.c_type, # Output, iq[2*m+1].
    utils._EngineFloat64ArrayType.c_type, # Output, rq[15*m+9].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim4_scat_shep_eval = utils._EngineState._get_symbol('e01tlf')
dim4_scat_shep_eval.restype = None
dim4_scat_shep_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[4, m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._EngineIntArrayType.c_type, # Input, iq[2*m+1].
    utils._EngineFloat64ArrayType.c_type, # Input, rq[15*m+9].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, xe[4, n].
    utils._EngineFloat64ArrayType.c_type, # Output, q[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qx[4, n].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim5_scat_shep = utils._EngineState._get_symbol('e01tmf')
dim5_scat_shep.restype = None
dim5_scat_shep.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[5, m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._BYREF_INT, # Input, nw.
    utils._BYREF_INT, # Input, nq.
    utils._EngineIntArrayType.c_type, # Output, iq[2*m+1].
    utils._EngineFloat64ArrayType.c_type, # Output, rq[21*m+11].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim5_scat_shep_eval = utils._EngineState._get_symbol('e01tnf')
dim5_scat_shep_eval.restype = None
dim5_scat_shep_eval.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[5, m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._EngineIntArrayType.c_type, # Input, iq[2*m+1].
    utils._EngineFloat64ArrayType.c_type, # Input, rq[21*m+11].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, xe[5, n].
    utils._EngineFloat64ArrayType.c_type, # Output, q[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qx[5, n].
    utils._BYREF_INT, # Input/Output, ifail.
)

dimn_grid = utils._EngineState._get_symbol('e01zaf')
dimn_grid.restype = None
dimn_grid.argtypes = (
    utils._BYREF_INT, # Input, d.
    utils._EngineIntArrayType.c_type, # Input, narr[d].
    utils._BYREF_LOGICAL, # Input, uniform.
    utils._EngineFloat64ArrayType.c_type, # Input, axis[lx].
    utils._BYREF_INT, # Input, lx.
    utils._EngineFloat64ArrayType.c_type, # Input, v[*].
    utils._EngineFloat64ArrayType.c_type, # Input, point[d].
    utils._BYREF_INT, # Input, method.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, wf.
    utils._BYREF_FLOAT64, # Output, ans.
    utils._BYREF_INT, # Input/Output, ifail.
)

dimn_scat_shep = utils._EngineState._get_symbol('e01zmf')
dimn_scat_shep.restype = None
dimn_scat_shep.argtypes = (
    utils._BYREF_INT, # Input, d.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[d, m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._BYREF_INT, # Input, nw.
    utils._BYREF_INT, # Input, nq.
    utils._EngineIntArrayType.c_type, # Output, iq[2*m+1].
    utils._EngineFloat64ArrayType.c_type, # Output, rq[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

dimn_scat_shep_eval = utils._EngineState._get_symbol('e01znf')
dimn_scat_shep_eval.restype = None
dimn_scat_shep_eval.argtypes = (
    utils._BYREF_INT, # Input, d.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[d, m].
    utils._EngineFloat64ArrayType.c_type, # Input, f[m].
    utils._EngineIntArrayType.c_type, # Input, iq[2*m+1].
    utils._EngineFloat64ArrayType.c_type, # Input, rq[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, xe[d, n].
    utils._EngineFloat64ArrayType.c_type, # Output, q[n].
    utils._EngineFloat64ArrayType.c_type, # Output, qx[d, n].
    utils._BYREF_INT, # Input/Output, ifail.
)
