# -*- coding: utf-8 -*-
u"""
Examples for the ``opt`` module.

``opt`` - Minimizing or Maximizing a Function

This module provides functions for solving various mathematical
optimization problems by solvers based on local stopping criteria.
The main classes of problems covered in this module are:

- Linear Programming (LP) -- dense and sparse;

- Quadratic Programming (QP) -- convex and nonconvex, dense and sparse;

- Nonlinear Programming (NLP) -- dense and sparse, based on active-set
  SQP methods or interior point methods (IPM);

- Second-order Cone Programming (SOCP);

- Semidefinite Programming (SDP) -- both linear matrix inequalities
  (LMI) and bilinear matrix inequalities (BMI);

- Derivative-free Optimization (DFO);

- Least Squares (LSQ), data fitting -- linear and nonlinear, constrained
  and unconstrained.

For a full overview of the functionality offered in this module, see
[the functionality index] or the Module Contents (submodule ``opt``).

See also other modules in the NAG Library relevant to optimization:

- submodule ``glopt`` contains functions to solve global optimization
  problems;

- submodule ``mip`` addresses problems arising in operational research
  and focuses on Mixed Integer Programming (MIP);

- submodule ``lapacklin`` and submodule ``lapackeig`` include functions
  for linear algebra and in particular unconstrained linear least
  squares;

- submodule ``fit`` focuses on curve and surface fitting, in which
  linear data fitting in l_1 or l_infinity norm might be of interest.

For full information please refer to the NAG Library document

https://www.nag.com/numeric/nl/nagdoc_27/flhtml/e04/e04intro.html
"""

# NAG Copyright 2017-2019.

pass
