"""
Deprecated wrappers for the NAG C Library (Mark 26.0) c09 Chapter.

c09 - Wavelet Transforms.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/C09/c09conts.html

NAG Copyright 2017.
"""
from ctypes import POINTER
from ctypes import c_double
from .util import get_library
from .util import Nag_Wavelet
from .util import Nag_WaveletTransform
from .util import Nag_WaveletMode
from .util import Integer
from .util import NagError
from .util import Nag_WaveletCoefficients

_library_cl = get_library()

c09aac_ctypes = _library_cl.c09aac
c09aac_ctypes.restype = None
c09aac_ctypes.argtypes = [Nag_Wavelet, Nag_WaveletTransform, Nag_WaveletMode, Integer, POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(NagError)]



def c09aac(wavnam, wtrans, mode, n, nwl, nf, nwc, icomm, fail):
    """
    One-dimensional wavelet filter initialization.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09aac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        nwl, nf, nwc, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        nwl, nf, nwc, icomm
    """
    from .util import nag_integer_type_check_and_cast
    _nwl = nag_integer_type_check_and_cast('c09aac', nwl, 'nwl')
    _nf = nag_integer_type_check_and_cast('c09aac', nf, 'nf')
    _nwc = nag_integer_type_check_and_cast('c09aac', nwc, 'nwc')
    _icomm = nag_integer_type_check_and_cast('c09aac', icomm, 'icomm')
    c09aac_ctypes(wavnam, wtrans, mode, n, _nwl, _nf, _nwc, _icomm, fail)

c09abc_ctypes = _library_cl.c09abc
c09abc_ctypes.restype = None
c09abc_ctypes.argtypes = [Nag_Wavelet, Nag_WaveletTransform, Nag_WaveletMode, Integer, Integer, POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def c09abc(wavnam, wtrans, mode, m, n, nwl, nf, nwct, nwcn, icomm, fail):
    """
    Two-dimensional wavelet filter initialization.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09abc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        nwl, nf, nwct, nwcn, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        nwl, nf, nwct, nwcn, icomm
    """
    from .util import nag_integer_type_check_and_cast
    _nwl = nag_integer_type_check_and_cast('c09abc', nwl, 'nwl')
    _nf = nag_integer_type_check_and_cast('c09abc', nf, 'nf')
    _nwct = nag_integer_type_check_and_cast('c09abc', nwct, 'nwct')
    _nwcn = nag_integer_type_check_and_cast('c09abc', nwcn, 'nwcn')
    _icomm = nag_integer_type_check_and_cast('c09abc', icomm, 'icomm')
    c09abc_ctypes(wavnam, wtrans, mode, m, n, _nwl, _nf, _nwct, _nwcn, _icomm, fail)

c09acc_ctypes = _library_cl.c09acc
c09acc_ctypes.restype = None
c09acc_ctypes.argtypes = [Nag_Wavelet, Nag_WaveletTransform, Nag_WaveletMode, Integer, Integer, Integer, POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def c09acc(wavnam, wtrans, mode, m, n, fr, nwl, nf, nwct, nwcn, nwcfr, icomm, fail):
    """
    Three-dimensional wavelet filter initialization.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09acc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        nwl, nf, nwct, nwcn, nwcfr, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        nwl, nf, nwct, nwcn, nwcfr, icomm
    """
    from .util import nag_integer_type_check_and_cast
    _nwl = nag_integer_type_check_and_cast('c09acc', nwl, 'nwl')
    _nf = nag_integer_type_check_and_cast('c09acc', nf, 'nf')
    _nwct = nag_integer_type_check_and_cast('c09acc', nwct, 'nwct')
    _nwcn = nag_integer_type_check_and_cast('c09acc', nwcn, 'nwcn')
    _nwcfr = nag_integer_type_check_and_cast('c09acc', nwcfr, 'nwcfr')
    _icomm = nag_integer_type_check_and_cast('c09acc', icomm, 'icomm')
    c09acc_ctypes(wavnam, wtrans, mode, m, n, fr, _nwl, _nf, _nwct, _nwcn, _nwcfr, _icomm, fail)

c09eyc_ctypes = _library_cl.c09eyc
c09eyc_ctypes.restype = None
c09eyc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def c09eyc(ilev, cindex, lenc, c, d, ldd, icomm, fail):
    """
    Two-dimensional discrete wavelet transform coefficient extraction.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09eyc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, d, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, d
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09eyc', c, 'c')
    _d = nag_double_type_check_and_cast('c09eyc', d, 'd')
    _icomm = nag_integer_type_check_and_cast('c09eyc', icomm, 'icomm')
    c09eyc_ctypes(ilev, cindex, lenc, _c, _d, ldd, _icomm, fail)

c09fyc_ctypes = _library_cl.c09fyc
c09fyc_ctypes.restype = None
c09fyc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, Integer, POINTER(Integer), POINTER(NagError)]


def c09fyc(ilev, cindex, lenc, c, d, ldd, sdd, icomm, fail):
    """
    Three-dimensional discrete wavelet transform coefficient extraction.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09fyc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, d, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, d
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09fyc', c, 'c')
    _d = nag_double_type_check_and_cast('c09fyc', d, 'd')
    _icomm = nag_integer_type_check_and_cast('c09fyc', icomm, 'icomm')
    c09fyc_ctypes(ilev, cindex, lenc, _c, _d, ldd, sdd, _icomm, fail)

c09ezc_ctypes = _library_cl.c09ezc
c09ezc_ctypes.restype = None
c09ezc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def c09ezc(ilev, cindex, lenc, c, d, ldd, icomm, fail):
    """
    Two-dimensional discrete wavelet transform coefficient insertion.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09ezc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, d, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, d
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09ezc', c, 'c')
    _d = nag_double_type_check_and_cast('c09ezc', d, 'd')
    _icomm = nag_integer_type_check_and_cast('c09ezc', icomm, 'icomm')
    c09ezc_ctypes(ilev, cindex, lenc, _c, _d, ldd, _icomm, fail)

c09fzc_ctypes = _library_cl.c09fzc
c09fzc_ctypes.restype = None
c09fzc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, Integer, POINTER(Integer), POINTER(NagError)]


def c09fzc(ilev, cindex, lenc, c, d, ldd, sdd, icomm, fail):
    """
    Three-dimensional discrete wavelet transform coefficient insertion.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09fzc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, d, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, d
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09fzc', c, 'c')
    _d = nag_double_type_check_and_cast('c09fzc', d, 'd')
    _icomm = nag_integer_type_check_and_cast('c09fzc', icomm, 'icomm')
    c09fzc_ctypes(ilev, cindex, lenc, _c, _d, ldd, sdd, _icomm, fail)

c09bac_ctypes = _library_cl.c09bac
c09bac_ctypes.restype = None
c09bac_ctypes.argtypes = [Nag_Wavelet, Integer, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def c09bac(wavnam, wparam, n, x, nscal, scales, c, fail):
    """
    One-dimensional real continuous wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09bac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x, scales, c
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, c
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        scales
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_double_type_check_and_cast('c09bac', x, 'x')
    _scales = nag_integer_type_check_and_cast('c09bac', scales, 'scales')
    _c = nag_double_type_check_and_cast('c09bac', c, 'c')
    c09bac_ctypes(wavnam, wparam, n, _x, nscal, _scales, _c, fail)

c09cac_ctypes = _library_cl.c09cac
c09cac_ctypes.restype = None
c09cac_ctypes.argtypes = [Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def c09cac(n, x, lenc, ca, cd, icomm, fail):
    """
    One-dimensional discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09cac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x, ca, cd, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, ca, cd
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_double_type_check_and_cast('c09cac', x, 'x')
    _ca = nag_double_type_check_and_cast('c09cac', ca, 'ca')
    _cd = nag_double_type_check_and_cast('c09cac', cd, 'cd')
    _icomm = nag_integer_type_check_and_cast('c09cac', icomm, 'icomm')
    c09cac_ctypes(n, _x, lenc, _ca, _cd, _icomm, fail)

c09cbc_ctypes = _library_cl.c09cbc
c09cbc_ctypes.restype = None
c09cbc_ctypes.argtypes = [Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def c09cbc(lenc, ca, cd, n, y, icomm, fail):
    """
    One-dimensional inverse discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09cbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ca, cd, y, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ca, cd, y
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ca = nag_double_type_check_and_cast('c09cbc', ca, 'ca')
    _cd = nag_double_type_check_and_cast('c09cbc', cd, 'cd')
    _y = nag_double_type_check_and_cast('c09cbc', y, 'y')
    _icomm = nag_integer_type_check_and_cast('c09cbc', icomm, 'icomm')
    c09cbc_ctypes(lenc, _ca, _cd, n, _y, _icomm, fail)

c09ccc_ctypes = _library_cl.c09ccc
c09ccc_ctypes.restype = None
c09ccc_ctypes.argtypes = [Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def c09ccc(n, x, lenc, c, nwl, dwtlev, icomm, fail):
    """
    One-dimensional multi-level discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09ccc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x, c, dwtlev, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, c
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        dwtlev, icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_double_type_check_and_cast('c09ccc', x, 'x')
    _c = nag_double_type_check_and_cast('c09ccc', c, 'c')
    _dwtlev = nag_integer_type_check_and_cast('c09ccc', dwtlev, 'dwtlev')
    _icomm = nag_integer_type_check_and_cast('c09ccc', icomm, 'icomm')
    c09ccc_ctypes(n, _x, lenc, _c, nwl, _dwtlev, _icomm, fail)

c09cdc_ctypes = _library_cl.c09cdc
c09cdc_ctypes.restype = None
c09cdc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def c09cdc(nwl, lenc, c, n, y, icomm, fail):
    """
    One-dimensional inverse multi-level discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09cdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, y, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, y
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09cdc', c, 'c')
    _y = nag_double_type_check_and_cast('c09cdc', y, 'y')
    _icomm = nag_integer_type_check_and_cast('c09cdc', icomm, 'icomm')
    c09cdc_ctypes(nwl, lenc, _c, n, _y, _icomm, fail)

c09dac_ctypes = _library_cl.c09dac
c09dac_ctypes.restype = None
c09dac_ctypes.argtypes = [Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def c09dac(n, x, lenc, ca, cd, icomm, fail):
    """
    One-dimensional maximal overlap discrete wavelet transform (MODWT).
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09dac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x, ca, cd, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, ca, cd
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_double_type_check_and_cast('c09dac', x, 'x')
    _ca = nag_double_type_check_and_cast('c09dac', ca, 'ca')
    _cd = nag_double_type_check_and_cast('c09dac', cd, 'cd')
    _icomm = nag_integer_type_check_and_cast('c09dac', icomm, 'icomm')
    c09dac_ctypes(n, _x, lenc, _ca, _cd, _icomm, fail)

c09dbc_ctypes = _library_cl.c09dbc
c09dbc_ctypes.restype = None
c09dbc_ctypes.argtypes = [Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def c09dbc(lenc, ca, cd, n, y, icomm, fail):
    """
    One-dimensional inverse maximal overlap discrete wavelet transform
    (IMODWT).
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09dbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ca, cd, y, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ca, cd, y
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ca = nag_double_type_check_and_cast('c09dbc', ca, 'ca')
    _cd = nag_double_type_check_and_cast('c09dbc', cd, 'cd')
    _y = nag_double_type_check_and_cast('c09dbc', y, 'y')
    _icomm = nag_integer_type_check_and_cast('c09dbc', icomm, 'icomm')
    c09dbc_ctypes(lenc, _ca, _cd, n, _y, _icomm, fail)

c09dcc_ctypes = _library_cl.c09dcc
c09dcc_ctypes.restype = None
c09dcc_ctypes.argtypes = [Integer, POINTER(c_double), Nag_WaveletCoefficients, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def c09dcc(n, x, keepa, lenc, c, nwl, na, icomm, fail):
    """
    One-dimensional multi-level maximal overlap discrete wavelet transform
    (MODWT).
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09dcc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x, c, na, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, c
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        na, icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_double_type_check_and_cast('c09dcc', x, 'x')
    _c = nag_double_type_check_and_cast('c09dcc', c, 'c')
    _na = nag_integer_type_check_and_cast('c09dcc', na, 'na')
    _icomm = nag_integer_type_check_and_cast('c09dcc', icomm, 'icomm')
    c09dcc_ctypes(n, _x, keepa, lenc, _c, nwl, _na, _icomm, fail)

c09ddc_ctypes = _library_cl.c09ddc
c09ddc_ctypes.restype = None
c09ddc_ctypes.argtypes = [Integer, Nag_WaveletCoefficients, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def c09ddc(nwlinv, keepa, lenc, c, n, y, icomm, fail):
    """
    One-dimensional inverse multi-level maximal overlap discrete wavelet
    transform (IMODWT).
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09ddc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, y, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, y
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09ddc', c, 'c')
    _y = nag_double_type_check_and_cast('c09ddc', y, 'y')
    _icomm = nag_integer_type_check_and_cast('c09ddc', icomm, 'icomm')
    c09ddc_ctypes(nwlinv, keepa, lenc, _c, n, _y, _icomm, fail)

c09eac_ctypes = _library_cl.c09eac
c09eac_ctypes.restype = None
c09eac_ctypes.argtypes = [Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def c09eac(m, n, a, pda, ca, pdca, ch, pdch, cv, pdcv, cd, pdcd, icomm, fail):
    """
    Two-dimensional discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09eac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        a, ca, ch, cv, cd, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        a, ca, ch, cv, cd
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _a = nag_double_type_check_and_cast('c09eac', a, 'a')
    _ca = nag_double_type_check_and_cast('c09eac', ca, 'ca')
    _ch = nag_double_type_check_and_cast('c09eac', ch, 'ch')
    _cv = nag_double_type_check_and_cast('c09eac', cv, 'cv')
    _cd = nag_double_type_check_and_cast('c09eac', cd, 'cd')
    _icomm = nag_integer_type_check_and_cast('c09eac', icomm, 'icomm')
    c09eac_ctypes(m, n, _a, pda, _ca, pdca, _ch, pdch, _cv, pdcv, _cd, pdcd, _icomm, fail)

c09ebc_ctypes = _library_cl.c09ebc
c09ebc_ctypes.restype = None
c09ebc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def c09ebc(m, n, ca, pdca, ch, pdch, cv, pdcv, cd, pdcd, b, pdb, icomm, fail):
    """
    Two-dimensional inverse discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09ebc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ca, ch, cv, cd, b, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ca, ch, cv, cd, b
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ca = nag_double_type_check_and_cast('c09ebc', ca, 'ca')
    _ch = nag_double_type_check_and_cast('c09ebc', ch, 'ch')
    _cv = nag_double_type_check_and_cast('c09ebc', cv, 'cv')
    _cd = nag_double_type_check_and_cast('c09ebc', cd, 'cd')
    _b = nag_double_type_check_and_cast('c09ebc', b, 'b')
    _icomm = nag_integer_type_check_and_cast('c09ebc', icomm, 'icomm')
    c09ebc_ctypes(m, n, _ca, pdca, _ch, pdch, _cv, pdcv, _cd, pdcd, _b, pdb, _icomm, fail)

c09ecc_ctypes = _library_cl.c09ecc
c09ecc_ctypes.restype = None
c09ecc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), Integer, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def c09ecc(m, n, a, pda, lenc, c, nwl, dwtlvm, dwtlvn, icomm, fail):
    """
    Two-dimensional multi-level discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09ecc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        a, c, dwtlvm, dwtlvn, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        a, c
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        dwtlvm, dwtlvn, icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _a = nag_double_type_check_and_cast('c09ecc', a, 'a')
    _c = nag_double_type_check_and_cast('c09ecc', c, 'c')
    _dwtlvm = nag_integer_type_check_and_cast('c09ecc', dwtlvm, 'dwtlvm')
    _dwtlvn = nag_integer_type_check_and_cast('c09ecc', dwtlvn, 'dwtlvn')
    _icomm = nag_integer_type_check_and_cast('c09ecc', icomm, 'icomm')
    c09ecc_ctypes(m, n, _a, pda, lenc, _c, nwl, _dwtlvm, _dwtlvn, _icomm, fail)

c09edc_ctypes = _library_cl.c09edc
c09edc_ctypes.restype = None
c09edc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), Integer, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def c09edc(nwl, lenc, c, m, n, b, pdb, icomm, fail):
    """
    Two-dimensional inverse multi-level discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09edc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, b, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, b
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09edc', c, 'c')
    _b = nag_double_type_check_and_cast('c09edc', b, 'b')
    _icomm = nag_integer_type_check_and_cast('c09edc', icomm, 'icomm')
    c09edc_ctypes(nwl, lenc, _c, m, n, _b, pdb, _icomm, fail)

c09fac_ctypes = _library_cl.c09fac
c09fac_ctypes.restype = None
c09fac_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), Integer, Integer, Integer, POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def c09fac(m, n, fr, a, lda, sda, lenc, c, icomm, fail):
    """
    Three-dimensional discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09fac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        a, c, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        a, c
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _a = nag_double_type_check_and_cast('c09fac', a, 'a')
    _c = nag_double_type_check_and_cast('c09fac', c, 'c')
    _icomm = nag_integer_type_check_and_cast('c09fac', icomm, 'icomm')
    c09fac_ctypes(m, n, fr, _a, lda, sda, lenc, _c, _icomm, fail)

c09fbc_ctypes = _library_cl.c09fbc
c09fbc_ctypes.restype = None
c09fbc_ctypes.argtypes = [Integer, Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, Integer, POINTER(Integer), POINTER(NagError)]


def c09fbc(m, n, fr, lenc, c, b, ldb, sdb, icomm, fail):
    """
    Three-dimensional inverse discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09fbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, b, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, b
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09fbc', c, 'c')
    _b = nag_double_type_check_and_cast('c09fbc', b, 'b')
    _icomm = nag_integer_type_check_and_cast('c09fbc', icomm, 'icomm')
    c09fbc_ctypes(m, n, fr, lenc, _c, _b, ldb, sdb, _icomm, fail)

c09fcc_ctypes = _library_cl.c09fcc
c09fcc_ctypes.restype = None
c09fcc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), Integer, Integer, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def c09fcc(m, n, fr, a, lda, sda, lenc, c, nwl, dwtlvm, dwtlvn, dwtlvfr, icomm, fail):
    """
    Three-dimensional multi-level discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09fcc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        a, c, dwtlvm, dwtlvn, dwtlvfr, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        a, c
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        dwtlvm, dwtlvn, dwtlvfr, icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _a = nag_double_type_check_and_cast('c09fcc', a, 'a')
    _c = nag_double_type_check_and_cast('c09fcc', c, 'c')
    _dwtlvm = nag_integer_type_check_and_cast('c09fcc', dwtlvm, 'dwtlvm')
    _dwtlvn = nag_integer_type_check_and_cast('c09fcc', dwtlvn, 'dwtlvn')
    _dwtlvfr = nag_integer_type_check_and_cast('c09fcc', dwtlvfr, 'dwtlvfr')
    _icomm = nag_integer_type_check_and_cast('c09fcc', icomm, 'icomm')
    c09fcc_ctypes(m, n, fr, _a, lda, sda, lenc, _c, nwl, _dwtlvm, _dwtlvn, _dwtlvfr, _icomm, fail)

c09fdc_ctypes = _library_cl.c09fdc
c09fdc_ctypes.restype = None
c09fdc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), Integer, Integer, Integer, POINTER(c_double), Integer, Integer, POINTER(Integer), POINTER(NagError)]


def c09fdc(nwlinv, lenc, c, m, n, fr, b, ldb, sdb, icomm, fail):
    """
    Three-dimensional inverse multi-level discrete wavelet transform.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/c09/c09fdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, b, icomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, b
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('c09fdc', c, 'c')
    _b = nag_double_type_check_and_cast('c09fdc', b, 'b')
    _icomm = nag_integer_type_check_and_cast('c09fdc', icomm, 'icomm')
    c09fdc_ctypes(nwlinv, lenc, _c, m, n, fr, _b, ldb, sdb, _icomm, fail)

nag_wfilt = c09aac
nag_wfilt_2d = c09abc
nag_wfilt_3d = c09acc
nag_wav_2d_coeff_ext = c09eyc
nag_wav_3d_coeff_ext = c09fyc
nag_wav_2d_coeff_ins = c09ezc
nag_wav_3d_coeff_ins = c09fzc
nag_cwt_1d_real = c09bac
nag_dwt = c09cac
nag_idwt = c09cbc
nag_mldwt = c09ccc
nag_imldwt = c09cdc
nag_modwt = c09dac
nag_imodwt = c09dbc
nag_mlmodwt = c09dcc
nag_imlmodwt = c09ddc
nag_dwt_2d = c09eac
nag_idwt_2d = c09ebc
nag_mldwt_2d = c09ecc
nag_imldwt_2d = c09edc
nag_dwt_3d = c09fac
nag_idwt_3d = c09fbc
nag_mldwt_3d = c09fcc
nag_imldwt_3d = c09fdc
__all__ = ['c09aac', 'c09abc', 'c09acc', 'c09bac', 'c09cac', 'c09cbc',
           'c09ccc', 'c09cdc', 'c09dac', 'c09dbc', 'c09dcc', 'c09ddc',
           'c09eac', 'c09ebc', 'c09ecc', 'c09edc', 'c09eyc', 'c09ezc',
           'c09fac', 'c09fbc', 'c09fcc', 'c09fdc', 'c09fyc', 'c09fzc',
           'nag_cwt_1d_real', 'nag_dwt', 'nag_dwt_2d', 'nag_dwt_3d',
           'nag_idwt', 'nag_idwt_2d', 'nag_idwt_3d', 'nag_imldwt',
           'nag_imldwt_2d', 'nag_imldwt_3d', 'nag_imlmodwt',
           'nag_imodwt', 'nag_mldwt', 'nag_mldwt_2d', 'nag_mldwt_3d',
           'nag_mlmodwt', 'nag_modwt', 'nag_wav_2d_coeff_ext',
           'nag_wav_2d_coeff_ins', 'nag_wav_3d_coeff_ext',
           'nag_wav_3d_coeff_ins', 'nag_wfilt', 'nag_wfilt_2d',
           'nag_wfilt_3d']
