"""
Deprecated wrappers for the NAG C Library (Mark 26.0) f06 Chapter.

f06 - Linear Algebra Support Functions.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/F06/f06conts.html

NAG Copyright 2017.
"""
from ctypes import c_double
from ctypes import POINTER

from .util import get_library
from .util import Complex
from .util import Integer
_library_cl = get_library()


f06fec_ctypes = _library_cl.f06fec
f06fec_ctypes.restype = None
f06fec_ctypes.argtypes = [Integer, c_double, POINTER(c_double), Integer]


def f06fec(n, alpha, x, incx):
    """
    Multiply real vector by reciprocal of scalar.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/f06/f06fec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    """
    from .util import nag_double_type_check_and_cast
    _x = nag_double_type_check_and_cast('f06fec', x, 'x')
    f06fec_ctypes(n, alpha, _x, incx)

f06kec_ctypes = _library_cl.f06kec
f06kec_ctypes.restype = None
f06kec_ctypes.argtypes = [Integer, c_double, POINTER(Complex), Integer]


def f06kec(n, alpha, x, incx):
    """
    Multiply complex vector by reciprocal of real scalar.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/f06/f06kec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x
    TypeError will be raised when the following arguments are not of data type
    Complex:
        x
    """
    from .util import nag_complex_type_check_and_cast
    _x = nag_complex_type_check_and_cast('f06kec', x, 'x')
    f06kec_ctypes(n, alpha, _x, incx)

nag_drscl = f06fec
nag_zrscl = f06kec
__all__ = ['f06fec', 'f06kec', 'nag_drscl', 'nag_zrscl']
