"""
Deprecated wrappers for the NAG C Library (Mark 26.0) h05 Functions.

h05 - Feature Selection.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/h/hconts.html

NAG Copyright 2017.
"""
from ctypes import c_double
from ctypes import POINTER

from .util import get_library

from .util import Integer
from .util import NagError
from .util import NAG_H05ABC_F
from .util import Nag_Comm

_library_cl = get_library()

h05aac_ctypes = _library_cl.h05aac
h05aac_ctypes.restype = None
h05aac_ctypes.argtypes = [POINTER(Integer), Integer, Integer, Integer, Integer, POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(Integer), POINTER(c_double), POINTER(Integer), Integer, c_double, POINTER(c_double), POINTER(Integer), Integer, POINTER(c_double), Integer, POINTER(NagError)]


def h05aac(irevcm, mincr, m, ip, nbest, drop, lz, z, la, a, bscore, bz, mincnt, gamma, acc, icomm, licomm, rcomm, lrcomm, fail):
    """
    Best n subsets of size p (reverse communication).
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/h/h05aac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        irevcm, drop, lz, z, la, a, bscore, bz, acc, icomm, rcomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        bscore, acc, rcomm
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        irevcm, drop, lz, z, la, a, bz, icomm
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _irevcm = nag_integer_type_check_and_cast('h05aac', irevcm, 'irevcm')
    _drop = nag_integer_type_check_and_cast('h05aac', drop, 'drop')
    _lz = nag_integer_type_check_and_cast('h05aac', lz, 'lz')
    _z = nag_integer_type_check_and_cast('h05aac', z, 'z')
    _la = nag_integer_type_check_and_cast('h05aac', la, 'la')
    _a = nag_integer_type_check_and_cast('h05aac', a, 'a')
    _bscore = nag_double_type_check_and_cast('h05aac', bscore, 'bscore')
    _bz = nag_integer_type_check_and_cast('h05aac', bz, 'bz')
    _acc = nag_double_type_check_and_cast('h05aac', acc, 'acc')
    _icomm = nag_integer_type_check_and_cast('h05aac', icomm, 'icomm')
    _rcomm = nag_double_type_check_and_cast('h05aac', rcomm, 'rcomm')
    h05aac_ctypes(_irevcm, mincr, m, ip, nbest, _drop, _lz, _z, _la, _a, _bscore, _bz, mincnt, gamma, _acc, _icomm, licomm, _rcomm, lrcomm, fail)

h05abc_ctypes = _library_cl.h05abc
h05abc_ctypes.restype = None
h05abc_ctypes.argtypes = [Integer, Integer, Integer, Integer, POINTER(Integer), POINTER(c_double), POINTER(Integer), NAG_H05ABC_F, Integer, c_double, POINTER(c_double), POINTER(Nag_Comm), POINTER(NagError)]


def h05abc(mincr, m, ip, nbest, la, bscore, bz, f, mincnt, gamma, acc, comm, fail):
    """
    Best n subsets of size p (direct communication).
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/h/h05abc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        la, bscore, bz, acc
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        bscore, acc
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        la, bz
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _la = nag_integer_type_check_and_cast('h05abc', la, 'la')
    _bscore = nag_double_type_check_and_cast('h05abc', bscore, 'bscore')
    _bz = nag_integer_type_check_and_cast('h05abc', bz, 'bz')
    _acc = nag_double_type_check_and_cast('h05abc', acc, 'acc')
    h05abc_ctypes(mincr, m, ip, nbest, _la, _bscore, _bz, f, mincnt, gamma, _acc, comm, fail)

nag_best_subset_given_size_revcomm = h05aac
nag_best_subset_given_size = h05abc
__all__ = ['h05aac', 'h05abc', 'nag_best_subset_given_size',
           'nag_best_subset_given_size_revcomm']
